
// Author: Chaivit Poovanich
// October 14, 1998

#ifndef DICTPATH_INC
#define DICTPATH_INC

#ifdef WIN32
#define PATHSEPERATOR "\\"
#else
#define PATHSEPERATOR "/"
#endif

#define D2TRIE "swathdic.tri"


#endif
